@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -59,9 +59,7 @@ AutoCorrectionLanguage::AutoCorrectionLanguage(QWidget *parent)
     model()->sort(0);
 }
 
-AutoCorrectionLanguage::~AutoCorrectionLanguage()
-{
-}
+AutoCorrectionLanguage::~AutoCorrectionLanguage() = default;
 
 QString AutoCorrectionLanguage::language() const
 {
