@@ -1,23 +1,21 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kactionmenuchangecasetest.h"
 #include "../src/pimcommon/widgets/kactionmenuchangecase.h"
-#include <QTest>
-#include <QSignalSpy>
 #include <QMenu>
+#include <QSignalSpy>
+#include <QTest>
 using namespace PimCommon;
 KActionMenuChangeCaseTest::KActionMenuChangeCaseTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-KActionMenuChangeCaseTest::~KActionMenuChangeCaseTest()
-{
-}
+KActionMenuChangeCaseTest::~KActionMenuChangeCaseTest() = default;
 
 void KActionMenuChangeCaseTest::shouldHaveDefaultValue()
 {
