@@ -2,13 +2,13 @@
   This file is part of libkdepim.
 
   SPDX-FileCopyrightText: 2006 Christian Schaarschmidt <schaarsc@gmx.de>
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kmailcompletion.h"
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QSet>
 
 using namespace PimCommon;
@@ -31,7 +31,7 @@ QString KMailCompletion::makeCompletion(const QString &string)
     // this should be in postProcessMatch, but postProcessMatch is const and will not allow nextMatch
     if (!match.isEmpty()) {
         const QString firstMatch(match);
-        while (match.indexOf(QRegExp(QLatin1String("(@)|(<.*>)"))) == -1) {
+        while (match.indexOf(QRegularExpression(QLatin1String("(@)|(<.*>)"))) == -1) {
             /* local email do not require @domain part, if match is an address we'll
              * find last+first <match> in m_keyMap and we'll know that match is
              * already a valid email.
