@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -14,9 +14,7 @@ BlackListBalooEmailListTest::BlackListBalooEmailListTest(QObject *parent)
 {
 }
 
-BlackListBalooEmailListTest::~BlackListBalooEmailListTest()
-{
-}
+BlackListBalooEmailListTest::~BlackListBalooEmailListTest() = default;
 
 void BlackListBalooEmailListTest::shouldHaveDefaultValue()
 {
@@ -32,7 +30,7 @@ void BlackListBalooEmailListTest::shouldFillListEmail()
     for (int i = 0; i < blackList.count(); ++i) {
         QListWidgetItem *item = blackList.item(i);
         QVERIFY(item);
-        auto *blackListItem = static_cast<PimCommon::BlackListBalooEmailListItem *>(item);
+        auto blackListItem = static_cast<PimCommon::BlackListBalooEmailListItem *>(item);
         QVERIFY(!blackListItem->initializeStatus());
         QCOMPARE(blackListItem->checkState(), Qt::Unchecked);
     }
@@ -50,7 +48,7 @@ void BlackListBalooEmailListTest::shouldFillListWithAlreadyBlackListedEmail()
     for (int i = 0; i < blackList.count(); ++i) {
         QListWidgetItem *item = blackList.item(i);
         QVERIFY(item);
-        auto *blackListItem = static_cast<PimCommon::BlackListBalooEmailListItem *>(item);
+        auto blackListItem = static_cast<PimCommon::BlackListBalooEmailListItem *>(item);
         QVERIFY(blackListItem->initializeStatus());
         QCOMPARE(blackListItem->checkState(), Qt::Checked);
     }
@@ -109,8 +107,7 @@ void BlackListBalooEmailListTest::shouldAvoidSameEmailWithDifferentCase()
 void BlackListBalooEmailListTest::shouldAvoidSameEmailWithDisplayNameOrNot()
 {
     PimCommon::BlackListBalooEmailList blackList;
-    const QStringList emails = QStringList() << QStringLiteral("foo@kde.org")
-                                             << QStringLiteral("Bla Blo <Foo@kde.org>");
+    const QStringList emails = QStringList() << QStringLiteral("foo@kde.org") << QStringLiteral("Bla Blo <Foo@kde.org>");
     QCOMPARE(blackList.setEmailFound(emails), 1);
 
     QCOMPARE(blackList.count(), 1);
